@@ -238,6 +238,7 @@ QSize ValueWidget::sizeHint() const
 QWidget* WidgetFactory::createValueWidget(const QString& value, QWidget* parent)
 {
     ValueWidget* valueWidget = new ValueWidget(parent);
+    valueWidget->setTextInteractionFlags(Qt::TextSelectableByMouse | Qt::TextSelectableByKeyboard);
     valueWidget->setWordWrap(true);
     valueWidget->setAlignment(Qt::AlignTop | Qt::AlignLeft);
     valueWidget->setText(m_readOnly ? plainText(value) : value);
@@ -252,8 +253,12 @@ QWidget* WidgetFactory::createValueWidget(const QString& value, QWidget* parent)
 
 void WidgetFactory::slotCommentChanged(const QString& comment)
 {
-    for (const QString& filePath : m_items) {
-        KFileMetaData::UserMetaData md(filePath);
+    for (const KFileItem& item : qAsConst(m_items)) {
+        QUrl url = item.targetUrl();
+        if (!url.isLocalFile()) {
+            continue;
+        }
+        KFileMetaData::UserMetaData md(url.toLocalFile());
         md.setUserComment(comment);
     }
     emit dataChangeStarted();
@@ -262,8 +267,12 @@ void WidgetFactory::slotCommentChanged(const QString& comment)
 
 void WidgetFactory::slotRatingChanged(uint rating)
 {
-    for (const QString& filePath : m_items) {
-        KFileMetaData::UserMetaData md(filePath);
+    for (const KFileItem& item : qAsConst(m_items)) {
+        QUrl url = item.targetUrl();
+        if (!url.isLocalFile()) {
+            continue;
+        }
+        KFileMetaData::UserMetaData md(url.toLocalFile());
         md.setRating(rating);
     }
     emit dataChangeStarted();
@@ -273,8 +282,12 @@ void WidgetFactory::slotRatingChanged(uint rating)
 void WidgetFactory::slotTagsChanged(const QStringList& tags)
 {
     if (m_tagWidget) {
-        for (const QString& filePath : m_items) {
-            KFileMetaData::UserMetaData md(filePath);
+        for (const KFileItem& item : qAsConst(m_items)) {
+            QUrl url = item.targetUrl();
+            if (!url.isLocalFile()) {
+                continue;
+            }
+            KFileMetaData::UserMetaData md(url.toLocalFile());
 
             // When multiple tags are selected one doesn't want to loose the old tags
             // of any of the resources. Unless specifically removed.
@@ -307,7 +320,7 @@ void WidgetFactory::slotLinkActivated(const QString& url)
 void WidgetFactory::slotTagClicked(const QString& tag)
 {
     QUrl url;
-    url.setScheme("tags");
+    url.setScheme(QStringLiteral("tags"));
     url.setPath(tag);
 
     emit urlActivated(url);
@@ -327,7 +340,7 @@ void WidgetFactory::setNoLinks(bool value)
     m_noLinks = value;
 }
 
-void WidgetFactory::setItems(const QStringList& items)
+void WidgetFactory::setItems(const KFileItemList& items)
 {
     m_items = items;
 }
